# Listening for commands on this PC's tcp port 2331
target remote localhost:2331

# Set gdb server to little endian
monitor endian little

# Set JTAG speed to 30 kHz
monitor speed 30

# Reset the chip to get to a known state.
monitor reset 8
monitor sleep 10

# 
# Init CPU
#

# Disable watchdog 
monitor writeu32 0xfffffd44 = 0x00008000 # WDT_MR_OFF

# Use 2 cycles for flash access
monitor writeu32 0xffffff60 = 0x00000100 # MC_FMR_OFF
monitor writeu32 0xffffff70 = 0x00000100 # MC_FMR_OFF

# Disable all interrupts
monitor writeu32 0xfffff130 = 0xffffffff # AIC_EOICR_OFF	
monitor writeu32 0xfffff124 = 0xffffffff # AIC_IDCR_OFF	

#
# Enable the main oscillator. Set startup time of 6 * 8 slow 
# clock cycles and wait until oscillator is stabilized.
#
monitor writeu32 0xFFFFFC20 = 0x00000601 # CKGR_MOR_OFF
monitor sleep 10

#
# Set PLL:
# PLLfreq = crystal / divider * (multiplier + 1)
# Wait 28 clock cycles until PLL is locked.
#
monitor writeu32 0xFFFFFC2C = 0x00481c0e # CKGR_PLLR_OFF
monitor sleep 10

#
# Set master clock prescaler.
#
monitor writeu32 0xFFFFFC30 = 0x00000004 # PMC_MCKR_OFF
monitor sleep 10

#
# Switch to PLL clock.
#
monitor writeu32 0xFFFFFC30 = 0x00000007 # PMC_MCKR_OFF
monitor sleep 10

#
# REMAP SDRAM to 0x00000000
monitor writeu32  0xFFFFFF00 = 1

#
# Enable SDRAM interface
#

# Enable SDRAM control at PIO A.
monitor writeu32 0xfffff474 = 0x3f800000 # PIO_BSR_OFF
monitor writeu32 0xfffff404 = 0x3f800000 # PIO_PDR_OFF

# Enable address bus (A0, A2-A11, A13-A17) at PIO B
monitor writeu32 0xfffff674 = 0x0003effd # PIO_BSR_OFF
monitor writeu32 0xfffff604 = 0x0003effd # PIO_PDR_OFF

# Enable 16 bit data bus at PIO C
monitor writeu32 0xfffff870 = 0x0000ffff # PIO_ASR_OFF
monitor writeu32 0xfffff804 = 0x0000ffff # PIO_PDR_OFF

# Enable SDRAM chip select
monitor writeu32 0xffffff80 = 0x00000002 # EBI_CSA_OFF

# Set SDRAM characteristics in configuration register.
# Hard coded values for MT48LC32M16A2 with 48MHz CPU.
monitor writeu32 0xffffffb8 = 0x2192215a # SDRAMC_CR_OFF
monitor sleep 10

# Issue 16 bit SDRAM command: NOP
monitor writeu32 0xffffffb0 = 0x00000011 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 

# Issue 16 bit SDRAM command: Precharge all
monitor writeu32 0xffffffb0 = 0x00000012 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 

# Issue 8 auto-refresh cycles
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 
monitor writeu32 0xffffffb0 = 0x00000014 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000 

# Issue 16 bit SDRAM command: Set mode register  
monitor writeu32 0xffffffb0 = 0x00000013 # SDRAMC_MR_OFF
monitor writeu32 0x20000014 = 0xcafedede

# Set refresh rate count 
monitor writeu32 0xffffffb4 = 384        # SDRAMC_TR_OFF

# Issue 16 bit SDRAM command: Normal mode
monitor writeu32 0xffffffb0 = 0x00000010 # SDRAMC_MR_OFF
monitor writeu32 0x20000000 = 0x00000000

monitor sleep 10


#
# Enable external reset key.
#
monitor writeu32 0xfffffd08 = 0xa5000001

# Set JTAG speed in khz
monitor speed auto

#load
#break main
#continue